@@ -3,10 +3,15 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.06";
+our $VERSION = "0.10";
 
 use Exporter qw/import/;
-our @EXPORT_OK = qw/pick pick_by/;
+our @EXPORT_OK = qw/
+    pick
+    pick_by
+    omit
+    omit_by
+/;
 
 use XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -22,7 +27,6 @@ Hash::Util::Pick - The non-destructive utilities for picking hash
 
 =head1 SYNOPSIS
 
-    use feature qw/say/;
     use Hash::Util::Pick qw/pick/;
 
     my $src = {
@@ -48,10 +52,22 @@ Create hash reference picked by special keys.
     pick { foo => 0, bar => 1 } => qw/foo/; # { foo => 0 }
 
 =head2 C<pick_by(\%hash, \&predicate)>
-Create hash reference picked by bloc block.
+Create hash reference picked by block.
 
     pick_by { foo => 0, bar => 1 } => sub { $_ > 0 }; # { bar => 1 }
 
+=head2 C<omit(\%hash, @keys)>
+Create hash reference omitted by special keys.
+
+    omit { } => qw/foo/; # { }
+    omit { foo => 0 } => qw/bar/; # { foo => 0 }
+    omit { foo => 0, bar => 1 } => qw/foo/; # { bar => 1 }
+
+=head2 C<omit_by(\%hash, \&predicate)>
+Create hash reference omitted by block.
+
+    omit_by { foo => 0, bar => 1 } => sub { $_ > 0 }; # { foo => 0 }
+
 =head1 LICENSE
 
 The MIT License (MIT)
